﻿using SQLite;
using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Net.Http;
using System.Text;
using Windows.Data.Json;
using Windows.Data.Xml.Dom;
using Windows.Foundation;
using Windows.Foundation.Collections;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Controls.Primitives;
using Windows.UI.Xaml.Data;
using Windows.UI.Xaml.Input;
using Windows.UI.Xaml.Media;
using Windows.UI.Xaml.Navigation;
using Windows.Web.Syndication;

namespace W8Data
{
	public sealed partial class MainPage : Page
	{
		public MainPage()
		{
			this.InitializeComponent();
		}

		protected override void OnNavigatedTo(NavigationEventArgs e)
		{
		}

		private async void CreateDatabase_Click(object sender, RoutedEventArgs e)
		{
			var conn = new SQLiteAsyncConnection("Customers");
			await conn.CreateTableAsync<Customer>();
		}

		private async void Insert_Click(object sender, RoutedEventArgs e)
		{
			SQLiteAsyncConnection conn = new SQLiteAsyncConnection("Customers");

			var c = new Customer
			{
				Name = "Stefano Mostarda",
				Address = "Via Del corso 1",
				City = "Roma",
				Country = "Italia",
				ZipCode = "00100"
			};

			await conn.InsertAsync(c);
		}

		private async void Select_Click(object sender, RoutedEventArgs e)
		{
			var conn = new SQLiteAsyncConnection("Customers");

			var query = conn.Table<Customer>().Where(x => x.City == "Roma");
			var result = await query.ToListAsync();
		}

		private async void SelectCustomersFromWEBAPIJSON_Click(object sender, RoutedEventArgs e)
		{
			var client = new HttpClient();
			var data = await client.GetStringAsync("http://localhost:15450/api/customers");

			var json = JsonArray.Parse(data);
			for (var i = 0; i < json.Count; i++)
			{
				var name = json[i].GetObject().GetNamedString("Name");
				var id = json[i].GetObject().GetNamedNumber("Id");
			}
		}

		private async void SelectCustomerFromWEBAPIJSON_Click(object sender, RoutedEventArgs e)
		{
			var client = new HttpClient();
			var data = await client.GetStringAsync("http://localhost:15450/api/customers/1");

			var json = JsonObject.Parse(data);
			var name = json.GetNamedString("Name");
			var id = json.GetNamedNumber("Id");
		}

		private async void InsertCustomerFromWEBAPIJSON_Click(object sender, RoutedEventArgs e)
		{
			var client = new HttpClient();
			Customer c = new Customer { Name = "Andrea Colaci", Address = "Via della grana 1", City = "Milano", Country = "Italia", ZipCode = "12345" };

			var j = new Windows.Data.Json.JsonObject();
			j.Add("Id", JsonValue.CreateNumberValue(c.Id));
			j.Add("Name", JsonValue.CreateStringValue(c.Name));
			j.Add("Address", JsonValue.CreateStringValue(c.Address));
			j.Add("City", JsonValue.CreateStringValue(c.City));
			j.Add("Country", JsonValue.CreateStringValue(c.Country));
			j.Add("ZipCode", JsonValue.CreateStringValue(c.ZipCode));
			StringContent content = new StringContent(j.Stringify(), Encoding.UTF8, "application/json");
			var data = await client.PostAsync("http://localhost:15450/api/customers", content);
		}

		private async void SelectCustomersFromWEBAPIXML_Click(object sender, RoutedEventArgs e)
		{
			var client = new HttpClient();
			client.DefaultRequestHeaders.Add("Accept", "application/xml");
			var data = await client.GetStringAsync("http://localhost:15450/api/customers");


			var doc = new XmlDocument();
			doc.LoadXml(data);
			foreach (var customer in doc.FirstChild.ChildNodes)
			{
				var Id = customer.ChildNodes.First(n => n.NodeName == "Id").InnerText;
				var Name = customer.ChildNodes.First(n => n.NodeName == "Name").InnerText;
			}
		}

		private async void SelectCustomerFromWEBAPIXML_Click(object sender, RoutedEventArgs e)
		{
			var client = new HttpClient();
			client.DefaultRequestHeaders.Add("Accept", "application/xml");
			var data = await client.GetStringAsync("http://localhost:15450/api/customers/1");

			var doc = new XmlDocument();
			doc.LoadXml(data);
			var customer = doc.FirstChild;
			var Id = customer.ChildNodes.First(n => n.NodeName == "Id").InnerText;
			var Name = customer.ChildNodes.First(n => n.NodeName == "Name").InnerText;
		}

		private async void InsertCustomerFromWEBAPIXML_Click(object sender, RoutedEventArgs e)
		{
			Customer c = new Customer { Name = "Andrea Colaci", Address = "Via della grana 1", City = "Milano", Country = "Italia", ZipCode = "12345" };

			XmlDocument obj = new XmlDocument();
			var root = obj.CreateElement("Customer");

			var id = obj.CreateElement("Id");
			id.InnerText = c.Id.ToString();

			var name = obj.CreateElement("Name");
			name.InnerText = c.Name.ToString();

			var address = obj.CreateElement("Address");
			address.InnerText = c.Address.ToString();

			var city = obj.CreateElement("City");
			city.InnerText = c.City.ToString();

			var country = obj.CreateElement("Country");
			country.InnerText = c.Country.ToString();

			var zipCode = obj.CreateElement("ZipCode");
			zipCode.InnerText = c.ZipCode.ToString();
			root.AppendChild(id).AppendChild(name).AppendChild(city).AppendChild(country).AppendChild(zipCode);
			obj.AppendChild(root);
			StringContent content = new StringContent(obj.GetXml(), Encoding.UTF8, "application/xml");
			HttpClient client = new HttpClient();
			var response = await client.PostAsync("http://localhost:15450/api/customers", content);
			response.EnsureSuccessStatusCode();
		}

		private async void GetFeedRSS_Click(object sender, RoutedEventArgs e)
		{
			SyndicationClient client = new SyndicationClient();
			var feed = await client.RetrieveFeedAsync(new Uri("http://weblogs.asp.net/scottgu/rss.aspx"));
			foreach (var item in feed.Items)
			{
				var text = item.Summary.Text;
				var title = item.Title.Text;
				var pubdate = item.PublishedDate;
				var url = item.Links[0].Uri.ToString();
			}
		}
	}
}
